# SysTool v.0.05.00

Reune funções úteis para o tratamento e visualização de dados. 
Uso particular em Engenharia de Transportes.

Módulos já utilizáveis:

- systool.data
    - Módulo de input e tratamento de dados relacionados à Engenharia de Transportes.
- systool.plot
    - Módulo de plot de gráficos e mapas relacionados à Engenharia de Transportes.
- systool.linreg
    - Módulo de cálculo e plot de regressões lineares relacionadas à Engenharia de Transportes.
- systool.distribution
    - Módulo de cálculo de distribuições matriciais relacionadas ao Modelo 4 Etapas de Engenharia de Transportes.
- systool.geo
    - Módulo de processamento de dados geográficos relacionados à Engenharia de Transportes.

Instalação:

Para a utilização desse módulo, se você usa Linux basta realizar: python3 pip install systool.
Se você utiliza windows, necessita instalar o Geopandas através do Anaconda, para isso, siga os passos abaixo:
1 - Acesse o site https://www.anaconda.com/products/distribution e faça o download da distribuição.
2 - Faça a instalação.
3 - Abra o Anaconda Prompt e crie um environment através de "conda create -n NomeDoSeuEnvAqui".
4 - Ative o environment com "conda activate NomeDoSeuEnvAqui".
5 - Use o comando "pip install systool".
6 - Pode utilizar o complemento agora a vontade!

Obs: Lembre de sempre ativar o ambiente antes de usar...
